@@ -3,7 +3,7 @@ GUI = [
     "brave",
     "code",
     "git",
-    "wezterm",
+    # "wezterm",  # needs admin
 ]
 
 # AI/LLM Tools - AI-powered coding and chat assistants
@@ -14,7 +14,7 @@ AGENTS = [
     "gemini",
     "crush",
     "opencode-ai",
-    "ollama",
+    # "ollama",
     "chatgpt",
     "mods",
     "q",
@@ -193,6 +193,7 @@ PACKAGES_FILE = [
     "winget",
     "fd",
     "fzf",
+    "tv",
     "broot",
     "rg",
     "rga",
