@@ -1,6 +1,6 @@
 
 import machineconfig.scripts.python.helpers_devops.cli_share_file
-import machineconfig.scripts.python.helpers_devops.cli_terminal as cli_terminal
+import machineconfig.scripts.python.helpers_devops.cli_share_terminal as cli_share_terminal
 import machineconfig.scripts.python.helpers_devops.cli_share_server as cli_share_server
 import typer
 from typing import Optional, Annotated
@@ -26,33 +26,32 @@ def add_ssh_key(path: Annotated[Optional[str], typer.Option(..., help="Path to t
          github: Annotated[Optional[str], typer.Option(..., "--github", "-g", help="Fetch public keys from a GitHub username")] = None
 ):
     """🔑 SSH add pub key to this machine so its accessible by owner of corresponding private key."""
-    import machineconfig.scripts.python.nw.devops_add_ssh_key as helper
+    import machineconfig.scripts.python.helpers_network.devops_add_ssh_key as helper
     helper.main(pub_path=path, pub_choose=choose, pub_val=value, from_github=github)
 def add_ssh_identity():
     """🗝️ SSH add identity (private key) to this machine"""
-    import machineconfig.scripts.python.nw.devops_add_identity as helper
+    import machineconfig.scripts.python.helpers_network.devops_add_identity as helper
     helper.main()
 
 
-def show_address():
+def show_address() -> None:
     """📌 Show this computer addresses on network"""
     from machineconfig.utils.installer_utils.installer_cli import install_if_missing
-    from pathlib import Path
-    from machineconfig.utils.accessories import randstr
-    tmp_file = Path.home().joinpath("tmp_results/tmp_files/ipinfo_result_" + randstr(8) + ".json")
-    tmp_file.parent.mkdir(parents=True, exist_ok=True)
+    import subprocess
     install_if_missing("ipinfo")
-    script = f"""
-ipinfo myip --json > "{tmp_file.as_posix()}"
-"""
-    from machineconfig.utils.code import run_shell_script
-    run_shell_script(script=script)
+    result = subprocess.run(
+        ["ipinfo", "myip", "--json"],
+        check=True,
+        capture_output=True,
+        text=True,
+        encoding="utf-8",
+    )
     import json
-    loaded_json = json.loads(tmp_file.read_text(encoding="utf-8"))
+    loaded_json = json.loads(result.stdout)
     from rich import print_json
     print_json(data=loaded_json)
 
-    import machineconfig.scripts.python.nw.address as helper
+    import machineconfig.scripts.python.helpers_network.address as helper
     from rich.table import Table
     from rich.console import Console
     res = helper.get_all_ipv4_addresses()
@@ -98,10 +97,10 @@ def debug_ssh():
     """🐛 SSH debug"""
     from platform import system
     if system() == "Linux" or system() == "Darwin":
-        import machineconfig.scripts.python.nw.ssh_debug_linux as helper
+        import machineconfig.scripts.python.helpers_network.ssh_debug_linux as helper
         helper.ssh_debug_linux()
     elif system() == "Windows":
-        import machineconfig.scripts.python.nw.ssh_debug_windows as helper
+        import machineconfig.scripts.python.helpers_network.ssh_debug_windows as helper
         helper.ssh_debug_windows()
     else:
         raise NotImplementedError(f"Platform {system()} is not supported.")
@@ -115,7 +114,7 @@ def wifi_select(
     from rich.panel import Panel
     from rich.prompt import Confirm
     from rich.console import Console
-    from machineconfig.scripts.python.nw.wifi_conn import try_config_connection, manual_network_selection, display_available_networks
+    from machineconfig.scripts.python.helpers_network.wifi_conn import try_config_connection, manual_network_selection, display_available_networks
     console = Console()
     console.print(Panel("📶 Welcome to the WiFi Connector Tool", title="[bold blue]WiFi Connection[/bold blue]", border_style="blue"))
 
@@ -176,8 +175,8 @@ sudo warp-cli connect
 
 def get_app():
     nw_apps = typer.Typer(help="🔐 [n] Network subcommands", no_args_is_help=True, add_help_option=False, add_completion=False)
-    nw_apps.command(name="share-terminal", help="📡  [t] Share terminal via web browser")(cli_terminal.share_terminal)
-    nw_apps.command(name="t", help="Share terminal via web browser", hidden=True)(cli_terminal.share_terminal)
+    nw_apps.command(name="share-terminal", help="📡  [t] Share terminal via web browser")(cli_share_terminal.share_terminal)
+    nw_apps.command(name="t", help="Share terminal via web browser", hidden=True)(cli_share_terminal.share_terminal)
 
     nw_apps.command(name="share-server", help="🌐  [s] Start local/global server to share files/folders via web browser", no_args_is_help=True)(cli_share_server.web_file_explorer)
     nw_apps.command(name="s", help="Start local/global server to share files/folders via web browser", hidden=True, no_args_is_help=True)(cli_share_server.web_file_explorer)
