@@ -1,10 +1,19 @@
 
-from typing import Any, Optional, Callable
+from typing import Any, Literal, Optional, Callable, cast
 from machineconfig.utils.accessories import randstr
-from machineconfig.utils.meta import lambda_to_python_script
 from pathlib import Path
 
 
+def get_uv_run_command(platform: str) -> str:
+    res = cast(Literal["Windows", "windows", "nt", "Linux", "linux", "Darwin", "darwin", "macos"], platform)
+    match res:
+        case "Windows" | "windows" | "nt":
+            return """& "$env:USERPROFILE/.local/bin/uv" run"""
+        case "Linux" | "linux" | "Darwin" | "darwin" | "macos":
+            return """$HOME/.local/bin/uv run"""
+        case _:
+            return """$HOME/.local/bin/uv run"""
+
 def print_code(code: str, lexer: str, desc: str, subtitle: str = ""):
     import platform
     try:
@@ -26,26 +35,38 @@ def print_code(code: str, lexer: str, desc: str, subtitle: str = ""):
         print(f"--- End of {desc} ---")
 
 
-def get_uv_command_executing_python_script(python_script: str, uv_with: Optional[list[str]], uv_project_dir: Optional[str]) -> tuple[str, Path]:
+def get_uv_command_executing_python_script(python_script: str, uv_with: Optional[list[str]], uv_project_dir: Optional[str],
+                                           prepend_print: bool = True) -> tuple[str, Path]:
     python_file = Path.home().joinpath("tmp_results", "tmp_scripts", "python", randstr() + ".py")
     python_file.parent.mkdir(parents=True, exist_ok=True)
     if uv_with is not None and len(uv_with) > 0:
-        uv_with.append("rich")
+        if prepend_print: uv_with.append("rich")
         uv_with_arg = "--with " + '"' + ",".join(uv_with) + '"'
     else:
-        uv_with_arg = "--with rich"
+        if prepend_print:
+            uv_with_arg = "--with rich"
+        else:
+            uv_with_arg = ""
     if uv_project_dir is not None:
         uv_project_dir_arg = "--project" + f' "{uv_project_dir}"'
     else:
         uv_project_dir_arg = ""
-    print_code_string = lambda_to_python_script(lambda: print_code(code=python_script, lexer="python", desc="Temporary Python Script", subtitle="Executing via shell script"),
-                                                in_global=True, import_module=False)
-    python_file.write_text(print_code_string + "\n" + python_script, encoding="utf-8")
-    shell_script = f"""uv run {uv_with_arg} {uv_project_dir_arg}  {str(python_file)} """
+    
+    if prepend_print:
+        from machineconfig.utils.meta import lambda_to_python_script
+        print_code_string = lambda_to_python_script(lambda: print_code(code=python_script, lexer="python", desc="Temporary Python Script", subtitle="Executing via shell script"),
+                                                    in_global=True, import_module=False)
+        python_file.write_text(print_code_string + "\n" + python_script, encoding="utf-8")
+    else:
+        python_file.write_text(python_script, encoding="utf-8")
+    import platform
+    uv_run = get_uv_run_command(platform=platform.system())
+    shell_script = f"""{uv_run} {uv_with_arg} {uv_project_dir_arg}  {str(python_file)} """
     return shell_script, python_file
 
 
 def run_lambda_function(lmb: Callable[[], Any], uv_with: Optional[list[str]], uv_project_dir: Optional[str]) -> None:
+    from machineconfig.utils.meta import lambda_to_python_script
     code = lambda_to_python_script(lmb,
                                             in_global=True, import_module=False)
     uv_command, _py_file = get_uv_command_executing_python_script(python_script=code, uv_with=uv_with, uv_project_dir=uv_project_dir)
@@ -156,3 +177,5 @@ def exit_then_run_shell_script(script: str, strict: bool = False):
         run_shell_script(script)
     import sys
     sys.exit(0)
+
+
