@@ -1,35 +1,16 @@
-from machineconfig.utils.path_extended import PathExtended, DECOMPRESS_SUPPORTED_FORMATS
-from machineconfig.utils.source_of_truth import INSTALL_TMP_DIR, INSTALL_VERSION_ROOT
+from machineconfig.utils.installer_utils.installer_helper import install_deb_package, download_and_prepare
+from machineconfig.utils.path_extended import PathExtended
+from machineconfig.utils.source_of_truth import INSTALL_VERSION_ROOT
 from machineconfig.utils.installer_utils.installer_locator_utils import find_move_delete_linux, find_move_delete_windows, check_tool_exists
 from machineconfig.utils.schemas.installer.installer_types import InstallerData, get_os_name, get_normalized_arch
+from machineconfig.utils.installer_utils.github_release_bulk import (
+    get_repo_name_from_url,
+    get_release_info,
+)
 
 import platform
 import subprocess
-import json
-from typing import Optional, Any
-from urllib.parse import urlparse
-
-
-
-def install_deb_package(downloaded: PathExtended) -> None:
-    from rich import print as rprint
-    from rich.panel import Panel
-    print(f"📦 Installing .deb package: {downloaded}")
-    assert platform.system() == "Linux"
-    result = subprocess.run(f"sudo nala install -y {downloaded}", shell=True, capture_output=True, text=True)
-    success = result.returncode == 0 and result.stderr == ""
-    if not success:
-        from rich.console import Group
-        desc = "Installing .deb"
-        sub_panels = []
-        if result.stdout:
-            sub_panels.append(Panel(result.stdout, title="STDOUT", style="blue"))
-        if result.stderr:
-            sub_panels.append(Panel(result.stderr, title="STDERR", style="red"))
-        group_content = Group(f"❌ {desc} failed\nReturn code: {result.returncode}", *sub_panels)
-        rprint(Panel(group_content, title=desc, style="red"))
-    print("🗑️  Cleaning up .deb package...")
-    downloaded.delete(sure=True)
+from typing import Optional
 
 
 class Installer:
@@ -126,18 +107,10 @@ class Installer:
                     runpy.run_path(str(installer_path), run_name=None)["main"](self.installer_data, version=version)
                     version_to_be_installed = str(version)
             elif installer_arch_os.startswith("https://") or installer_arch_os.startswith("http://"):
-                # downloaded_object = PathExtended(installer_arch_os).download(folder=INSTALL_TMP_DIR)
-                from machineconfig.scripts.python.helpers_utils.download import download
-                downloaded_object = download(installer_arch_os, output_dir=str(INSTALL_TMP_DIR))
-                if downloaded_object is None:
-                    raise ValueError(f"Failed to download from URL: {installer_arch_os}")
-                # object is either a zip containing a binary or a straight out binary.
-                downloaded_object = PathExtended(downloaded_object)
-                if downloaded_object.suffix in DECOMPRESS_SUPPORTED_FORMATS:
-                    downloaded_object = downloaded_object.decompress()
+                downloaded_object = download_and_prepare(installer_arch_os)
                 if downloaded_object.suffix in [".exe", ""]:  # likely an executable
                     if platform.system() == "Windows":
-                        exe = find_move_delete_windows(downloaded_file_path=downloaded_object, exe_name=exe_name, delete=True, rename_to=exe_name.replace(".exe", "") + ".exe")
+                        exe = find_move_delete_windows(downloaded_file_path=downloaded_object, tool_name=exe_name, delete=True, rename_to=exe_name.replace(".exe", "") + ".exe")
                     elif platform.system() in ["Linux", "Darwin"]:
                         system_name = "Linux" if platform.system() == "Linux" else "macOS"
                         print(f"🐧 Installing on {system_name}...")
@@ -169,7 +142,7 @@ class Installer:
             if str(downloaded).endswith(".deb"): install_deb_package(downloaded)
             else:
                 if platform.system() == "Windows":
-                    exe = find_move_delete_windows(downloaded_file_path=downloaded, exe_name=exe_name, delete=True, rename_to=exe_name.replace(".exe", "") + ".exe")
+                    exe = find_move_delete_windows(downloaded_file_path=downloaded, tool_name=exe_name, delete=True, rename_to=exe_name.replace(".exe", "") + ".exe")
                 elif platform.system() in ["Linux", "Darwin"]:
                     system_name = "Linux" if platform.system() == "Linux" else "macOS"
                     print(f"🐧 Installing on {system_name}...")
@@ -195,7 +168,7 @@ class Installer:
         # app_name = self.installer_data["appName"]
         download_link: Optional[str] = None
         version_to_be_installed: Optional[str] = None
-        if "github" not in repo_url or (any(ext in repo_url for ext in DECOMPRESS_SUPPORTED_FORMATS)):
+        if "github" not in repo_url:
             # Direct download URL
             download_link = repo_url
             version_to_be_installed = "predefined_url"
@@ -209,56 +182,16 @@ class Installer:
             print(f"🧭 Detected system={os_name} arch={arch}")
             # Use existing get_github_release method to get download link and version
             download_link, version_to_be_installed = self.get_github_release(repo_url, version)
+            # print(f"🌟 Retrieved download link from GitHub: {download_link}")
+            # print(f"📦 Version to be installed: {version_to_be_installed}")
             if download_link is None:
                 raise ValueError(f"Could not retrieve download link for {exe_name} version {version or 'latest'}")
             print(f"📦 Version to be installed: {version_to_be_installed}")
             print(f"🔗 Download URL: {download_link}")
         assert download_link is not None, "download_link must be set"
         assert version_to_be_installed is not None, "version_to_be_installed must be set"
-        downloaded = PathExtended(download_link).download(folder=INSTALL_TMP_DIR).decompress()
-        if downloaded.is_dir() and len(downloaded.search("*", r=True)) == 1:
-            only_file_in = next(downloaded.glob("*"))
-            if only_file_in.is_file() and only_file_in.suffix in DECOMPRESS_SUPPORTED_FORMATS:  # further decompress
-                downloaded = only_file_in.decompress()
+        downloaded = download_and_prepare(download_link)
         return downloaded, version_to_be_installed
-    @staticmethod
-    def _get_repo_name_from_url(repo_url: str) -> str:
-        """Extract owner/repo from GitHub URL."""
-        try:
-            parsed = urlparse(repo_url)
-            path_parts = parsed.path.strip("/").split("/")
-            return f"{path_parts[0]}/{path_parts[1]}"
-        except (IndexError, AttributeError):
-            return ""
-
-    @staticmethod
-    def _fetch_github_release_data(repo_name: str, version: Optional[str] = None) -> Optional[dict[str, Any]]:
-        """Fetch release data from GitHub API using requests."""
-        import requests
-        try:
-            if version and version.lower() != "latest":  # Fetch specific version
-                url = f"https://api.github.com/repos/{repo_name}/releases/tags/{version}"
-            else:   # Fetch latest release
-                url = f"https://api.github.com/repos/{repo_name}/releases/latest"
-            response = requests.get(url, timeout=30)
-            if response.status_code != 200:
-                print(f"❌ Failed to fetch data for {repo_name}: HTTP {response.status_code}")
-                return None
-            response_data = response.json()
-            # Check if API returned an error
-            if "message" in response_data:
-                if "API rate limit exceeded" in response_data.get("message", ""):
-                    print(f"🚫 Rate limit exceeded for {repo_name}")
-                    return None
-                elif "Not Found" in response_data.get("message", ""):
-                    print(f"🔍 No releases found for {repo_name}")
-                    return None
-                    
-            return response_data
-            
-        except (requests.RequestException, requests.Timeout, json.JSONDecodeError) as e:
-            print(f"❌ Error fetching {repo_name}: {e}")
-            return None
 
     def get_github_release(self, repo_url: str, version: Optional[str]) -> tuple[Optional[str], Optional[str]]:
         """
@@ -270,20 +203,20 @@ class Installer:
         filename_pattern = self.installer_data["fileNamePattern"][arch][os_name]
         if filename_pattern is None:
             raise ValueError(f"No fileNamePattern for {self._get_exe_name()} on {os_name} {arch}")
-        repo_name = self._get_repo_name_from_url(repo_url)
-        if not repo_name:
+        repo_info = get_repo_name_from_url(repo_url)
+        if not repo_info:
             print(f"❌ Invalid repository URL: {repo_url}")
             return None, None
-        release_data = self._fetch_github_release_data(repo_name, version)
-        if not release_data:
+        username, repository = repo_info
+        release_info = get_release_info(username, repository, version)
+        if not release_info:
             return None, None        
-        # print(release_data)
-        actual_version = release_data.get("tag_name", "unknown")
+        actual_version = release_info.get("tag_name", "unknown") or "unknown"
         filename = filename_pattern.format(version=actual_version)
 
         available_filenames: list[str] = []
-        for asset in release_data.get("assets", []):
-            an_dl = asset.get("browser_download_url", "NA")
+        for asset in release_info["assets"]:
+            an_dl = asset["browser_download_url"]
             available_filenames.append(an_dl.split("/")[-1])
         if filename not in available_filenames:
             candidates = [
